.eslintrc.json
.npmrc
LICENSE
README.md
artifacts
captainhook.json
cli
components
composer.json
composer.lock
docs
ilias_version.php
lang
node_modules
package-lock.json
package.json
public
scripts
templates
unzip_test_file.zip
vendor
.htaccess
ilias.ini.php